{% extends "admin/base.html" %}
{% load static %}


{% block title %}{% if subtitle %}{{ subtitle }} | {% endif %}{{ title }} |
    {{ site_title|default:_('Django site admin') }}{% endblock %}

{% block branding %}
    {{ block.super }}





    <div id="site-name"><a href="{% url 'admin:index' %}">{{ site_header|default:_('Django administration') }}</a></div>
    {% if user.is_anonymous %}
        {% include "admin/color_theme_toggle.html" %}
    {% endif %}

    <a href="/django_notifications/admin/notifications/"
       class="button"
       style="{% if unread_notifications > 0 %}background-color: red; color: white;{% else %}background-color: blue; color: white;{% endif %}">
        Уведомления
    </a>
{% endblock %}

{% block nav-global %}{% endblock %}
