# Generated by Django 5.1.6 on 2025-02-28 13:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_notifications", "0001_initial"),
    ]

    operations = [
        migrations.AddField(
            model_name="notification",
            name="app_id_object",
            field=models.BigIntegerField(default=0),
        ),
    ]
