# Generated by Django 5.1.6 on 2025-02-28 12:05

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Notification",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                ("ident", models.BooleanField(default=True)),
                ("app_name_model", models.TextField()),
                ("app_name_ident", models.TextField()),
            ],
        ),
    ]
